@@ -351,12 +351,12 @@ static mpz_t x3, z3, x4, z4;  /* used by prac */
 #define DUP 5 /* number of multiplications in a double */
 
 /* Returns the number of mulmods */
-static UV lucas_cost(UV n, double v)
+static UV lucas_cost(UV n, double val)
 {
   UV c, d, e, r;
 
   d = n;
-  r = (UV) ( ((double)d / v) + 0.5 );
+  r = (UV) ( ((double)d / val) + 0.5 );
   if (r >=n )
     return(ADD*n);
   d = n - r;
@@ -396,18 +396,18 @@ static void ec_mult(UV k, mpz_t x, mpz_t z)
    unsigned int  d, e, r, i;
    __mpz_struct *xA, *zA, *xB, *zB, *xC, *zC, *xT, *zT, *xT2, *zT2, *t;
 
-   static double const v[] =
+   static double const val[] =
      {1.61803398875, 1.72360679775, 1.618347119656, 1.617914406529,
       1.58017872826};
 
-   /* chooses the best value of v */
+   /* chooses the best value of val */
    r = ADD * k;
    i = 0;
    for (d = 0; d < 5; d++) {
-     e = lucas_cost(k, v[d]);
+     e = lucas_cost(k, val[d]);
      if (e < r) { r = e;  i = d; }
    }
-   r = (unsigned int)((double)k / v[i] + 0.5);
+   r = (unsigned int)((double)k / val[i] + 0.5);
    /* A=(x:z) B=(x1:z1) C=(x2:z2) T=T1=(x3:z3) T2=(x4:z4) */
    xA=x; zA=z; xB=x1; zB=z1; xC=x2; zC=z2; xT=x3; zT=z3; xT2=x4; zT2=z4;
    /* first iteration always begins by Condition 3, then a swap */
