@@ -28,6 +28,7 @@ extern int proth(mpz_t N);
 
 extern UV   _GMP_trial_factor(mpz_t n, UV from_n, UV to_n);
 
+extern int  primality_pretest(mpz_t n);
 extern int  _GMP_is_prime(mpz_t n);
 extern int  _GMP_is_prob_prime(mpz_t n);
 extern int  _GMP_is_provable_prime(mpz_t n, char ** prooftext);
@@ -61,4 +62,8 @@ extern uint32_t* partial_sieve(mpz_t start, UV length, UV maxprime);
 extern char* pidigits(UV n);
 extern char* harmreal(mpz_t zn, unsigned long prec);
 
+extern UV* sieve_primes(mpz_t low, mpz_t high, UV k, UV *rn);
+extern UV* sieve_twin_primes(mpz_t low, mpz_t high, UV twin, UV *rn);
+extern UV* sieve_cluster(mpz_t low, mpz_t high, uint32_t* cl, UV nc, UV *rn);
+
 #endif
